==> knative-model-4.6.3-sources.jar: annotations/io/fabric8/knative/serving/v1/RouteStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.URLBuilder;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RouteStatusFluent<A extends RouteStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public RouteStatusFluent.AddressNested<A> withNewAddress();
    public RouteStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public RouteStatusFluent.AddressNested<A> editAddress();
    public RouteStatusFluent.AddressNested<A> editOrNewAddress();
    public RouteStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public RouteStatusFluent.ConditionsNested<A> addNewCondition();
    public RouteStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public RouteStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public RouteStatusFluent.ConditionsNested<A> editCondition(int index);
    public RouteStatusFluent.ConditionsNested<A> editFirstCondition();
    public RouteStatusFluent.ConditionsNested<A> editLastCondition();
    public RouteStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,TrafficTarget item);
    public A setToTraffic(int index,TrafficTarget item);
    public A addToTraffic(TrafficTarget... items);
    public A addAllToTraffic(Collection<TrafficTarget> items);
    public A removeFromTraffic(TrafficTarget... items);
    public A removeAllFromTraffic(Collection<TrafficTarget> items);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<TrafficTarget> getTraffic();
    public List<TrafficTarget> buildTraffic();
    public TrafficTarget buildTraffic(int index);
    public TrafficTarget buildFirstTraffic();
    public TrafficTarget buildLastTraffic();
    public TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public A withTraffic(List<TrafficTarget> traffic);
    public A withTraffic(TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> editTraffic(int index);
    public RouteStatusFluent.TrafficNested<A> editFirstTraffic();
    public RouteStatusFluent.TrafficNested<A> editLastTraffic();
    public RouteStatusFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildUrl instead.
 * @return The buildable object.
 */
@Deprecated public URL getUrl();
    public URL buildUrl();
    public A withUrl(URL url);
    public Boolean hasUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrlLike(URL item);
    public RouteStatusFluent.UrlNested<A> editUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrlLike(URL item);

    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<RouteStatusFluent.AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<RouteStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TrafficTargetFluent<RouteStatusFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}
    public interface UrlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<RouteStatusFluent.UrlNested<N>>{

        
    public N and();    public N endUrl();
}


}

==> knative-model-4.8.0-sources.jar: annotations/io/fabric8/knative/serving/v1/RouteStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.URLBuilder;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RouteStatusFluent<A extends RouteStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public RouteStatusFluent.AddressNested<A> withNewAddress();
    public RouteStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public RouteStatusFluent.AddressNested<A> editAddress();
    public RouteStatusFluent.AddressNested<A> editOrNewAddress();
    public RouteStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public RouteStatusFluent.ConditionsNested<A> addNewCondition();
    public RouteStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public RouteStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public RouteStatusFluent.ConditionsNested<A> editCondition(int index);
    public RouteStatusFluent.ConditionsNested<A> editFirstCondition();
    public RouteStatusFluent.ConditionsNested<A> editLastCondition();
    public RouteStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,TrafficTarget item);
    public A setToTraffic(int index,TrafficTarget item);
    public A addToTraffic(TrafficTarget... items);
    public A addAllToTraffic(Collection<TrafficTarget> items);
    public A removeFromTraffic(TrafficTarget... items);
    public A removeAllFromTraffic(Collection<TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<TrafficTarget> getTraffic();
    public List<TrafficTarget> buildTraffic();
    public TrafficTarget buildTraffic(int index);
    public TrafficTarget buildFirstTraffic();
    public TrafficTarget buildLastTraffic();
    public TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public A withTraffic(List<TrafficTarget> traffic);
    public A withTraffic(TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> editTraffic(int index);
    public RouteStatusFluent.TrafficNested<A> editFirstTraffic();
    public RouteStatusFluent.TrafficNested<A> editLastTraffic();
    public RouteStatusFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildUrl instead.
 * @return The buildable object.
 */
@Deprecated public URL getUrl();
    public URL buildUrl();
    public A withUrl(URL url);
    public Boolean hasUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrlLike(URL item);
    public RouteStatusFluent.UrlNested<A> editUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrlLike(URL item);

    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<RouteStatusFluent.AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<RouteStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TrafficTargetFluent<RouteStatusFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}
    public interface UrlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<RouteStatusFluent.UrlNested<N>>{

        
    public N and();    public N endUrl();
}


}
